@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Exporter qw/import/;
 
-our $VERSION       = q{1.00};
+our $VERSION       = q{1.01};
 our @EXPORT        = qw(dispatch on cases xdefault);
 our @EXPORT_OK     = qw(dispatch on cases xdefault);
 
@@ -34,6 +34,12 @@ sub dispatch (&@) {
     my $code_ref  = shift;    # catch sub ref that was coerced from the 'dispatch' BLOCK
     my $match_ref = shift;    # catch the input reference passed after the 'dispatch' BLOCK
     
+    # build up dispatch table for each k/v pair preceded by 'on'
+    while ( my $key = shift @_ ) {
+        my $HV = shift @_;
+        $DISPATCH_TABLE->{$key} = _to_sub($HV);
+    }
+    
     # call $code_ref that needs to return a valid bucket name
     my $key = $code_ref->($match_ref);
     
@@ -54,8 +60,13 @@ sub dispatch (&@) {
 
 # on accumulater, wants h => v pair, where h is a static bucket string and v is a sub ref
 sub on (@) {
-    my ($key, $HV) = @_;
-    $DISPATCH_TABLE->{$key} = _to_sub($HV);
+    my ($key, $val) = @_;
+    my $context = wantarray;
+    if (not defined $context) {
+      warn <<EOF;
+Warning: "on $key" used in void context is always a mistake. The "on" method always follows a comma!
+EOF
+    }
     return @_;
 }
 
@@ -91,12 +102,12 @@ Dispatch::Fu - Converts any complicated conditional dispatch situation into fami
 
   my $INPUT = [qw/1 2 3 4 5/];
 
-  my $results = dispatch {                       # <~ start of 'dispatch' construct
-      my $input_ref = shift;                     # <~ input reference
-      return ( scalar @$input_ref > 5 )          # <~ return a string that must be
-       ? q{case5}                                #    defined below using the 'on'
-       : sprintf qq{case%d}, scalar @$input_ref; #    keyword, this i
-  } $INPUT,                                      # <~ input reference, SCALAR passed to dispatch BLOCK
+  my $results = dispatch {                                      # <~ start of 'dispatch' construct
+      my $input_ref = shift;                                    # <~ input reference
+      return ( scalar @$input_ref > 5 )                         # <~ return a string that must be
+       ? q{case5}                                               # <~ defined below using the 'on'
+       : sprintf qq{case%d}, scalar @$input_ref;                # <~ dynamic dispatch here
+  } $INPUT,                                                     # <~ input reference, SCALAR passed to dispatch BLOCK
     on case0 => sub { my $INPUT = shift; return qq{case 0}},    # <~ if dispatch returns 'case0', run this CODE
     on case1 => sub { my $INPUT = shift; return qq{case 1}} ,   # <~ if dispatch returns 'case1', run this CODE
     on case2 => sub { my $INPUT = shift; return qq{case 2}},    #    ...   ...   ...   ...   ...   ...   ...
